==> sghi_core-0.2.38.tar.gz: lib/communities/components/avatar.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:sghi_core/communities/core/chat_api.dart';
import 'package:sghi_core/communities/core/community_utils.dart';
import 'package:sghi_core/communities/models/strings.dart';

class Avatar extends StatelessWidget {
  const Avatar({
    super.key,
    required this.avatarURI,
    required this.displayName,
    required this.color,
    this.aviSize = 50,
    this.textSize = 16,
  });

  final String? avatarURI;
  final String? displayName;
  final double aviSize;
  final double textSize;
  final Color color;

  @override
  Widget build(BuildContext context) {
    final bool emptyAvi = avatarURI == null ||
        (avatarURI?.isEmpty ?? true) ||
        avatarURI == UNKNOWN;

    final String aviMediaURL =
        ChatAPI.getMediaURL(mediaUrl: avatarURI ?? '') ?? '';

    if (!emptyAvi) {
      return ClipRRect(
        borderRadius: BorderRadius.circular(aviSize),
        child: CachedNetworkImage(
          height: aviSize,
          width: aviSize,
          fit: BoxFit.cover,
          imageUrl: aviMediaURL,
          progressIndicatorBuilder: (
            BuildContext context,
            String url,
            DownloadProgress progress,
          ) {
            return Center(
              child: Container(
                padding: const EdgeInsets.all(15),
                child: const CircularProgressIndicator(strokeWidth: 1),
              ),
            );
          },
        ),
      );
    } else {
      return Container(
        height: aviSize,
        width: aviSize,
        decoration: BoxDecoration(
          shape: BoxShape.circle,
          color: color.withOpacity(0.2),
        ),
        padding: const EdgeInsets.all(10),
        child: Center(
          child: Text(
            getInitials(displayName ?? noName).toUpperCase(),
            style: TextStyle(
              fontSize: textSize,
              fontWeight: FontWeight.w700,
              color: color,
            ),
          ),
        ),
      );
    }
  }
}

==> sghi_core-0.3.56.tar.gz: lib/communities/components/avatar.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:sghi_core/communities/core/chat_api.dart';
import 'package:sghi_core/communities/core/community_utils.dart';
import 'package:sghi_core/communities/models/strings.dart';

class Avatar extends StatelessWidget {
  const Avatar({
    super.key,
    required this.avatarURI,
    required this.displayName,
    required this.color,
    required this.baseUrl,
    required this.mediaServerUrl,
    this.aviSize = 50,
    this.textSize = 16,
  });

  final String? avatarURI;
  final String? displayName;
  final double aviSize;
  final double textSize;
  final Color color;
  final String baseUrl;
  final String mediaServerUrl;

  @override
  Widget build(BuildContext context) {
    final bool emptyAvi = avatarURI == null ||
        (avatarURI?.isEmpty ?? true) ||
        avatarURI == UNKNOWN;

    final String aviMediaURL = ChatAPI.getMediaURL(
          mediaUrl: avatarURI ?? '',
          baseUrl: baseUrl,
          mediaServerUrl: mediaServerUrl,
        ) ??
        '';

    if (!emptyAvi) {
      return ClipRRect(
        borderRadius: BorderRadius.circular(aviSize),
        child: CachedNetworkImage(
          height: aviSize,
          width: aviSize,
          fit: BoxFit.cover,
          imageUrl: aviMediaURL,
          progressIndicatorBuilder: (
            BuildContext context,
            String url,
            DownloadProgress progress,
          ) {
            return Center(
              child: Container(
                padding: const EdgeInsets.all(15),
                child: const CircularProgressIndicator(strokeWidth: 1),
              ),
            );
          },
        ),
      );
    } else {
      return Container(
        height: aviSize,
        width: aviSize,
        decoration: BoxDecoration(
          shape: BoxShape.circle,
          color: color.withOpacity(0.2),
        ),
        padding: const EdgeInsets.all(10),
        child: Center(
          child: Text(
            getInitials(displayName ?? noName).toUpperCase(),
            style: TextStyle(
              fontSize: textSize,
              fontWeight: FontWeight.w700,
              color: color,
            ),
          ),
        ),
      );
    }
  }
}
